body{overflow:hidden}div.websocketerror{background-color:red;border-color:#000;border-radius:2px;border-width:1px;height:16px;position:absolute;right:32px;top:12px;width:16px}div.masterdiv{height:100vh;left:0;overflow:hidden;position:absolute;top:0;width:100vw}.ticker{width:100%}.text-left{text-align:left}.text-center{text-align:center}.text-right{text-align:right}.pl-0{padding-left:0}.pl-1{padding-left:.25rem}.pl-2{padding-left:.5rem}.pr-0{padding-right:0}.pr-1{padding-right:.25rem}.pr-2{padding-right:.5rem}table.EinfachGruen{background-color:#eee;border:.1vh solid #21a428;border-collapse:collapse;width:100%}table.EinfachGruen td,table.EinfachGruen th{border:.1vh solid #aaa;padding:.3vh}table.EinfachGruen td{color:#222}table.EinfachGruen tr:nth-child(2n){background:#cef5c5}table.EinfachGruen th{background:#21a428;background:linear-gradient(180deg,#58bb5e 0,#37ad3d 66%,#21a428);border-bottom:.1vh solid #444;border-left:.1vh solid #d0e4f5;color:#fff;font-weight:700}table.EinfachBlau{background-color:#eee;border:.1vh solid #1c6ea4;border-collapse:collapse;width:100%}table.EinfachBlau th{background:#1c6ea4;background:linear-gradient(180deg,#5592bb 0,#327cad 66%,#1c6ea4);border-bottom:.1vh solid #444;border-left:.1vh solid #d0e4f5;color:#fff;font-weight:700}table.EinfachBlau td{color:#222}table.EinfachBlau td,table.EinfachBlau th{border:.1vh solid #aaa;padding:.3vh}table.EinfachBlau tr:nth-child(2n){background:#d0e4f5}table.Schwarz{background-color:#000;border:.1vh solid #000;border-collapse:collapse;color:#fff;width:100%}table.Schwarz td,table.Schwarz th{border:.1vh solid #fff;padding:.3vh}table.Schwarz th{background:#000;color:#fff;font-weight:700;text-align:left}table.Weis{background-color:#fff;border:.1vh solid #fff;border-collapse:collapse;color:#000;width:100%}table.Weis td,table.Weis th{border:.1vh solid #000;padding:.3vh}table.Weis th{background:#fff;color:#000;font-weight:700;text-align:left}table.Standard{border:.1vh solid;border-collapse:collapse;width:100%}table.Standard td,table.Standard th{border:.1vh solid;padding:.3vh}table.Standard tbody th{border-left:.1vh solid;font-weight:700}table.ZeilenBlau{border:0;border-collapse:seperate;border-spacing:0 1vh;width:100%}table.ZeilenBlau td,table.ZeilenBlau th{border:.1vh solid #000;padding:.3vh}table.ZeilenBlau th{background:#1c6ea4;border-color:#000;border-left:.1vh solid #000;color:#fff;font-weight:700}table.ZeilenBlau td{background:#d0e4f5;color:#222}table.ZeilenBlau th:first-child{border-bottom-left-radius:1vh;border-left-style:solid #000;border-top-left-radius:1vh}table.ZeilenBlau th:last-child{border-bottom-right-radius:1vh;border-right-style:solid #000;border-top-right-radius:1vh}table.ZeilenBlau td:first-child{border-bottom-left-radius:1vh;border-left-style:solid #000;border-top-left-radius:1vh}table.ZeilenBlau td:last-child{border-bottom-right-radius:1vh;border-right-style:solid #000;border-top-right-radius:1vh}table.ZeilenGruen{border:0;border-collapse:seperate;border-spacing:0 1vh;width:100%}table.ZeilenGruen td,table.ZeilenGruen th{border:.1vh solid #000;padding:.3vh}table.ZeilenGruen th{background:#21a428;border-color:#000;border-left:.1vh solid #000;color:#fff;font-weight:700}table.ZeilenGruen td{background:#cef5c5;color:#222}table.ZeilenGruen th:first-child{border-bottom-left-radius:1vh;border-left-style:solid #000;border-top-left-radius:1vh}table.ZeilenGruen th:last-child{border-bottom-right-radius:1vh;border-right-style:solid #000;border-top-right-radius:1vh}table.ZeilenGruen td:first-child{border-bottom-left-radius:1vh;border-left-style:solid #000;border-top-left-radius:1vh}table.ZeilenGruen td:last-child{border-bottom-right-radius:1vh;border-right-style:solid #000;border-top-right-radius:1vh}
/*# sourceMappingURL=main.4e2869b7.css.map*/